Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(115)

Unified Diff: webrtc/video_receive_stream.h

Issue 3000273002: Reverse |rtx_payload_types| map, and rename. (Closed)
Patch Set: Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/video_receive_stream.h
diff --git a/webrtc/video_receive_stream.h b/webrtc/video_receive_stream.h
index 48d16a8ea1b7f883d8652deceb694512c0946cfa..b9649736551df64cd59f30d7d9aabcd4f9a93cee 100644
--- a/webrtc/video_receive_stream.h
+++ b/webrtc/video_receive_stream.h
@@ -161,9 +161,9 @@ class VideoReceiveStream {
// Set if the stream is protected using FlexFEC.
bool protected_by_flexfec = false;
// Map from video payload type (apt) -> RTX payload type (pt).
// For RTX to be enabled, both an SSRC and this mapping are needed.
- std::map<int, int> rtx_payload_types;
+ std::map<int, int> media_pt_by_rtx_pt;
danilchap 2017/08/21 14:11:26 non-common abbreviations in names are strongly dis
nisse-webrtc 2017/08/22 07:11:01 My intention was to make the name so explicit that
danilchap 2017/08/22 08:09:55 I still find 'pt' both 'Only your group knows what
@@ -161,9 +161,9 @@ class VideoReceiveStream {
// Set if the stream is protected using FlexFEC.
bool protected_by_flexfec = false;
- // Map from video payload type (apt) -> RTX payload type (pt).
+ // Map from rtx payload type -> media payload type.
// For RTX to be enabled, both an SSRC and this mapping are needed.
// RTP header extensions used for the received stream.
std::vector<RtpExtension> extensions;
« webrtc/video/rtp_video_stream_receiver.cc ('K') | « webrtc/video/video_receive_stream.cc ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698